@@ -1,48 +1,32 @@
 package HTTP::Server::EV::MultipartFile;
 use File::Copy;
 use strict;
-our $VERSION = '0.1';
+our $VERSION = $HTTP::Server::EV::VERSION;
 
 =head1 NAME
-
 	HTTP::Server::EV::MultipartFile - represents file received by L<HTTP::Server::EV>
-
 =cut
 
-
 sub size {shift->{size}};
 sub name {shift->{name}};
 sub path {shift->{path}};
 
-
 =head1 FILE PARAMETERS
 
-=over
-
 =item $file->size or $file->{size} 
-
 Filesize in bytes
-
 =item $file->name or $file->{name}
-
 Filename received in http request
 
 =item $file->path or $file->{path}
-
-Path to tmp file. You don`t need to use this. Use $file->save() instead
-
-=back
+Path to tmp file. You don`t need to use this. Use $file->save instead
 
 =head1 METHODS
-
 =head2 $file->fh;
-
 Return filehandle opened to reading. Die on error
-
 =cut
 
 
-
 sub fh {
 	my $self = shift;
 	
@@ -54,14 +38,9 @@ sub fh {
 	return $self->{fh};
 }
 
-
 =head2 $file->save($path);
-
 Save received file to $path. Just moves file from tmp dir to $path if possible. Dies on error
-
 =cut
-
-
 sub save {
 	my ($self, $dest) = @_;
 	close delete $self->{fh} if $self->{fh};
@@ -77,12 +56,8 @@ sub save {
 
 
 =head2 $file->del;
-
 Delete file from tmp directory. You don`t need to use this method, L<HTTP::Server::EV::CGI> calls it on all request files on DESTROY
-
 =cut
-
-
 sub del {
 	my $self = shift;
 	
